@@ -1,6 +1,5 @@
 import time
-import pickle
-import socket
+from multiprocessing import connection
 import threading
 from typing import Union as _U
 
@@ -10,7 +9,7 @@ from pynput import keyboard
 
 class _Client:
     def __init__(self):
-        self.sock = None
+        self.conn = None
         self.robot_connected = False
         self.port = 4741
         self.open_connection()
@@ -25,25 +24,15 @@ class _Client:
         if port is not None:
             self.port = port
         try:
-            self.sock = socket.socket()
-            self.sock.settimeout(5)
-            self.sock.connect(("localhost", self.port))
+            self.conn = connection.Client(("localhost", self.port))
             self.robot_connected = self._send("connected", res=True)
             print("Connected to AlphAI, type help(alphai) for more info")
         except ConnectionRefusedError:
             print("No AlphAI instance running yet, you can connect by calling")
             print("alphai.open_api()")
-        except socket.timeout:
-            print(
-                "Connection to AlphAI impossible, you might be already "
-                "connected or trying on the wrong port. Try closing all "
-                "instances of Python or use another another port when calling "
-                "open_connection(port)")
-        finally:
-            self.sock.settimeout(None)
 
     def __del__(self):
-        self.sock.close()
+        self.conn.close()
 
     def _send(self, command, val=None, res=False):
         """
@@ -56,12 +45,9 @@ class _Client:
         :return: None if no response, the response otherwise
         """
         try:
-            self.sock.send(pickle.dumps((command, val)))
+            self.conn.send((command, val))
             if res:
-                # blocking call
-                pickle_size = pickle.loads(self.sock.recv(28))  # a pickle this
-                # small is size 28 bytes
-                return pickle.loads(self.sock.recv(pickle_size))
+                return self.conn.recv()
         except ConnectionResetError:
             print("No AlphAI instance running")
             if res:
@@ -143,13 +129,15 @@ class _Client:
         self._send("set_distance", value)
 
     def get_distance(self) -> float:
-        return self._send("get_distance", res=True)
+        return self._send("get_distance", res=True) * 100.
 
-    def get_camera(self) -> np.ndarray:
-        return self._send("get_camera", res=True)
+    def get_camera(self) -> list:
+        image = self._send("get_camera", res=True)
+        image = (image * 255).astype(np.uint8).tolist()
+        return image
 
-    def get_infra_red(self) -> np.ndarray:
-        return self._send("get_ir", res=True)
+    def get_infrared(self) -> list:
+        return self._send("get_ir", res=True).tolist()
 
     def get_blockade(self) -> bool:
         return self._send("get_blockade", res=True)
@@ -188,7 +176,12 @@ def connect(value: _U[str, bool, int] = True):
     integer for Bluetooth
     @return: True for a successful connection, False otherwise
     """
-    return _client.connect(value)
+    success = _client.connect(value)
+    if success:
+        print('Connection to robot successful')
+    else:
+        print('Connection to robot failed')
+    return success
 
 
 def connect_wifi():
@@ -275,12 +268,12 @@ def get_camera() -> np.ndarray:
     return _client.get_camera()
 
 
-def get_infra_red() -> np.ndarray:
+def get_infra_red() -> list:
     """
     get the current infrared values as an array
     @return: an array containing the infrared values
     """
-    return _client.get_infra_red()
+    return _client.get_infrared()
 
 
 def get_blockade() -> bool:
